==> 1.5.1.tar.gz: ios/Classes/PlatformViews/StoryBlockViewFactory.swift <==
//
//  StoryBlockViewFactory.swift
//  fw_flutter_sdk
//
//  Created by linjie jiang on 2022/8/9.
//

import FireworkVideo
import Flutter
import Foundation

class StoryBlockViewFactory: NSObject, FlutterPlatformViewFactory {
    private var messenger: FlutterBinaryMessenger

    init(messenger: FlutterBinaryMessenger) {
        self.messenger = messenger
        super.init()
    }

    func create(withFrame frame: CGRect, viewIdentifier viewId: Int64, arguments args: Any?)
        -> FlutterPlatformView {
        return StoryBlockContainerView(
            frame: frame, viewIdentifier: viewId, arguments: args, binaryMessenger: messenger)
    }

    public func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
        return FlutterStandardMessageCodec.sharedInstance()
    }
}

private class StoryBlockContainerView: NSObject, FlutterPlatformView, StoryBlockViewDelegate {
    private var _view: UIView
    var methodChannel: FlutterMethodChannel
    var storyBlock: StoryBlock!

    init(
        frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?,
        binaryMessenger messenger: FlutterBinaryMessenger
    ) {
        let channelName = String(
            format: FWChannelName.fireworkStoryBlockModule.rawValue, arguments: [viewId])
        methodChannel = FlutterMethodChannel.init(name: channelName, binaryMessenger: messenger)

        _view = UIView()
        super.init()
        createStoryBlockView(args as? [String: AnyObject])

    }

    func createStoryBlockView(_ args: [String: AnyObject]?) {
        storyBlock = StoryBlock()
        storyBlock.translatesAutoresizingMaskIntoConstraints = false
        storyBlock.delegate = self
        if let arguments = args {
            storyBlock.sourceType = RCTConvert.storyBlockSourceType(arguments["source"] as? String)
            if let channel = arguments["channel"] as? String {
                storyBlock.channel = channel
            }
            if let playlist = arguments["playlist"] as? String {
                storyBlock.playlist = playlist
            }

            if let dynamicContentParameters = arguments["dynamicContentParameters"]
                as? [String: [String]] {
                storyBlock.dynamicContentParameters = dynamicContentParameters
            }

            if let enablePictureInPicture = arguments["enablePictureInPicture"] as? Bool {
                storyBlock.enablePictureInPicture = enablePictureInPicture
            }
        }

        _view.addSubview(storyBlock)
        let constraints = storyBlock.constraints(equalTo: _view)
        NSLayoutConstraint.activate(
            constraints
        )
    }

    func view() -> UIView {
        return _view
    }

    func storyBlockDidLoadFeed(_ view: StoryBlock) {
        methodChannel.invokeMethod(
            StoryBlockEventName.onStoryBlockLoadFinished.rawValue, arguments: nil)
    }

    func storyBlock(_ view: StoryBlock, didFailToLoadFeed error: StoryBlockError) {
        methodChannel.invokeMethod(
            StoryBlockEventName.onStoryBlockLoadFinished.rawValue, arguments: error.jsObject)
    }
}

==> 2.0.4.tar.gz: ios/Classes/PlatformViews/StoryBlockViewFactory.swift <==
//
//  StoryBlockViewFactory.swift
//  fw_flutter_sdk
//
//  Created by linjie jiang on 2022/8/9.
//

import FireworkVideo
import Flutter
import Foundation

class StoryBlockViewFactory: NSObject, FlutterPlatformViewFactory {
    private var messenger: FlutterBinaryMessenger

    init(messenger: FlutterBinaryMessenger) {
        self.messenger = messenger
        super.init()
    }

    func create(withFrame frame: CGRect, viewIdentifier viewId: Int64, arguments args: Any?)
        -> FlutterPlatformView {
        return StoryBlockContainerView(
            frame: frame, viewIdentifier: viewId, arguments: args, binaryMessenger: messenger)
    }

    public func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
        return FlutterStandardMessageCodec.sharedInstance()
    }
}

private class StoryBlockContainerView: NSObject, FlutterPlatformView, StoryBlockDelegate {
    private var _view: UIView
    var methodChannel: FlutterMethodChannel
    var storyBlock: StoryBlock!

    init(
        frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?,
        binaryMessenger messenger: FlutterBinaryMessenger
    ) {
        _ = AppLanguageManager.shared

        let channelName = String(
            format: ChannelName.storyBlock.rawValue, arguments: [viewId])
        methodChannel = FlutterMethodChannel.init(name: channelName, binaryMessenger: messenger)

        _view = UIView()
        super.init()
        createStoryBlockView(args as? [String: AnyObject])
        setMethodCallHandler(methodChannel)
    }

    func createStoryBlockView(_ args: [String: AnyObject]?) {
        storyBlock = StoryBlock()
        storyBlock.translatesAutoresizingMaskIntoConstraints = false
        storyBlock.delegate = self
        if let arguments = args {
            storyBlock.sourceType = Convert.storyBlockSourceType(arguments["source"] as? String)
            if let channel = arguments["channel"] as? String {
                storyBlock.channel = channel
            }
            if let playlist = arguments["playlist"] as? String {
                storyBlock.playlist = playlist
            }

            if let dynamicContentParameters = arguments["dynamicContentParameters"]
                as? [String: [String]] {
                storyBlock.dynamicContentParameters = dynamicContentParameters
            }

            if let hashtagFilterExpression = arguments["hashtagFilterExpression"] as? String {
                storyBlock.hashtagFilterExpression = hashtagFilterExpression
            }

            storyBlock.adConfiguration = JsonHelper.fromDictionary(
                arguments["adConfiguration"] as? [String: AnyObject], type: AdConfiguration.self)

            if let enablePictureInPicture = arguments["enablePictureInPicture"] as? Bool {
                storyBlock.enablePictureInPicture = enablePictureInPicture
            }
        }

        _view.addSubview(storyBlock)
        let constraints = storyBlock.constraints(equalTo: _view)
        NSLayoutConstraint.activate(
            constraints
        )
    }

    func setMethodCallHandler(_ channel: FlutterMethodChannel) {
        channel.setMethodCallHandler { [weak self] (call: FlutterMethodCall, result: @escaping FlutterResult) -> Void in
            switch call.method {
            case StoryBlockMethodName.play.rawValue:
                self?.playStoryBlock()
                result(nil)
            case StoryBlockMethodName.pause.rawValue:
                self?.pauseStoryBlock()
                result(nil)
            default:
                result(FlutterMethodNotImplemented)
            }
        }
    }

    func playStoryBlock() {
        storyBlock.play()
    }

    func pauseStoryBlock() {
        storyBlock.pause()
    }

    func view() -> UIView {
        return _view
    }

    func storyBlockDidLoadFeed(_ view: StoryBlock) {
        methodChannel.invokeMethod(
            StoryBlockEventName.onStoryBlockLoadFinished.rawValue, arguments: nil)
    }

    func storyBlock(_ view: StoryBlock, didFailToLoadFeed error: StoryBlockError) {
        methodChannel.invokeMethod(
            StoryBlockEventName.onStoryBlockLoadFinished.rawValue, arguments: error.jsObject)
    }
}
